]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Remove a redundant check in passed pawn eval
[stockfish] / src / tt.h
index bcc761acf325da0999838b2f209cb4faab92bb33..46f5b11dd3940864ace0da1c377f95aa8411735d 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -110,15 +110,15 @@ public:
   TTEntry* retrieve(const Key posKey) const;
   void new_search();
   void insert_pv(const Position& pos, Move pv[]);
-  void extract_pv(const Position& pos, Move pv[], const int PLY_MAX);
+  void extract_pv(const Position& pos, Move bestMove, Move pv[], const int PLY_MAX);
   int full() const;
   TTEntry* first_entry(const Key posKey) const;
 
 private:
// Be sure 'writes' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];
-  unsigned writes; // heavy SMP read/write access here
+  unsigned overwrites; // heavy SMP read/write access here
   unsigned char pad_after[64];
 
   size_t size;
@@ -110,15 +110,15 @@ public:
 
 private:
-  // Be sure 'writes' is at least one cache line away
+  // Be sure 'overwrites' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];